"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processConfigSet = void 0;
const core_1 = require("@takomo/core");
const command_path_1 = require("./command-path");
const processConfigSet = async (holder, group, target, configSet, timer, state) => {
    const { io, ctx, input } = holder;
    io.info(`Execute config set: ${configSet.name}`);
    const stacksConfigRepository = await ctx.configRepository.createStacksConfigRepository(configSet.name, configSet.legacy);
    const results = new Array();
    const commandPaths = input.commandPath
        ? [input.commandPath]
        : configSet.commandPaths;
    for (const commandPath of commandPaths) {
        const commandPathTimer = timer.startChild(commandPath);
        try {
            const result = await (0, command_path_1.processCommandPath)(holder, group, target, configSet, commandPath, commandPathTimer, state, stacksConfigRepository);
            commandPathTimer.stop();
            results.push(result);
            if (!result.success) {
                state.failed = true;
            }
        }
        catch (e) {
            io.error(`Unhandled error when executing group: ${group.path}, target: ${target.name}, config set: ${configSet.name}, command path: ${commandPath}`, e);
            state.failed = true;
            results.push({
                commandPath,
                result: {
                    message: e.message,
                    status: "FAILED",
                    timer,
                    outputFormat: input.outputFormat,
                    success: false,
                    results: [],
                },
                success: false,
                status: "FAILED",
                message: "Failed",
            });
        }
    }
    timer.stop();
    return {
        ...(0, core_1.resolveCommandOutputBase)(results),
        outputFormat: input.outputFormat,
        configSetName: configSet.name,
        results,
        timer,
    };
};
exports.processConfigSet = processConfigSet;
//# sourceMappingURL=config-set.js.map